/* 这是针对缺省样式 (必须的) */
::-webkit-scrollbar {
    width: 5px;
    height: 5px;
}

/* 滚动条的滑轨背景颜色 */
::-webkit-scrollbar-track {
    background-color: rgba(0, 0, 0, 0.5);
    -webkit-border-radius: 2em;
    -moz-border-radius: 2em;
    border-radius: 2em;
}

/* 滑块颜色 */
::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, 0.5);
    -webkit-border-radius: 2em;
    -moz-border-radius: 2em;
    border-radius: 2em;
}

/* 滑轨两头的监听按钮颜色 */
::-webkit-scrollbar-button {
    -webkit-border-radius: 2em;
    -moz-border-radius: 2em;
    border-radius: 2em;
    width: 0;
    height: 0;
    background-color: rgba(0, 0, 0, 0.6);
}

/* 横向滚动条和纵向滚动条相交处尖角的颜色 */
::-webkit-scrollbar-corner {
    background-color: rgba(0, 0, 0, 0.6);
}

.window-body .sidebar .sidebar-body .catalog-body ul li .text {
    width: 100%;
}

.window-body .workspace .article .article-head .tools {
    background: #F1F1F1;
}

@media only screen and (min-width: 960px) {
    .window-body .workspace .article .article-body {
        max-width: 96%;
    }
}
